==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/TemplateSectionHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata } from "./TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata";
import { SectionHeaderDescriptionMetadata } from "./SectionHeaderDescriptionMetadata";
import { TemplateSectionHeaderDescription } from "./TemplateSectionHeaderDescription";
/**
 * @hidden
 */
export let TemplateSectionHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateSectionHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateSectionHeaderDescriptionMetadata.a == null) {
                TemplateSectionHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateSectionHeaderDescriptionMetadata.c(TemplateSectionHeaderDescriptionMetadata.a);
            }
            if (a.k(TemplateSectionHeaderDescriptionMetadata.a)) {
                return;
            }
            a.ab(TemplateSectionHeaderDescriptionMetadata.a);
            TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            SectionHeaderDescriptionMetadata.c(a);
            a.item("CellUpdatingRef", "EventRef::cellUpdating");
        }
        static d(a) {
            TemplateSectionHeaderDescriptionMetadata.b(a);
            a.ad("TemplateSectionHeader", () => new TemplateSectionHeaderDescription());
            a.ac("TemplateSectionHeader", TemplateSectionHeaderDescriptionMetadata.a);
        }
    }
    TemplateSectionHeaderDescriptionMetadata.$t = markType(TemplateSectionHeaderDescriptionMetadata, 'TemplateSectionHeaderDescriptionMetadata');
    TemplateSectionHeaderDescriptionMetadata.a = null;
    return TemplateSectionHeaderDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/TemplateSectionHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata } from "./TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata";
import { SectionHeaderDescriptionMetadata } from "./SectionHeaderDescriptionMetadata";
import { TemplateSectionHeaderDescription } from "./TemplateSectionHeaderDescription";
/**
 * @hidden
 */
export let TemplateSectionHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateSectionHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateSectionHeaderDescriptionMetadata.a == null) {
                TemplateSectionHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateSectionHeaderDescriptionMetadata.c(TemplateSectionHeaderDescriptionMetadata.a);
            }
            if (a.k(TemplateSectionHeaderDescriptionMetadata.a)) {
                return;
            }
            a.ac(TemplateSectionHeaderDescriptionMetadata.a);
            TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            SectionHeaderDescriptionMetadata.c(a);
            a.item("CellUpdatingRef", "EventRef::cellUpdating");
        }
        static d(a) {
            TemplateSectionHeaderDescriptionMetadata.b(a);
            a.ae("TemplateSectionHeader", () => new TemplateSectionHeaderDescription());
            a.ad("TemplateSectionHeader", TemplateSectionHeaderDescriptionMetadata.a);
        }
    }
    TemplateSectionHeaderDescriptionMetadata.$t = markType(TemplateSectionHeaderDescriptionMetadata, 'TemplateSectionHeaderDescriptionMetadata');
    TemplateSectionHeaderDescriptionMetadata.a = null;
    return TemplateSectionHeaderDescriptionMetadata;
})();
